﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SimpleStackBar
{
    /// <summary>
    /// Interaction logic for UserControl1.xaml
    /// </summary>
    public partial class SimpleStackBar : UserControl
    {
        private readonly Brush[] DefaultBrushes = { new BrushConverter().ConvertFromString("#FF9AC6E0") as Brush,
                                                       new BrushConverter().ConvertFromString("#FFB7E690") as Brush,
                                                      Brushes.Black,
                                                      Brushes.BlueViolet };

        public SimpleStackBar()
        {
            InitializeComponent();
        }

        public static readonly DependencyProperty SeriesProperty = DependencyProperty.Register("Series", typeof(BarSeries), typeof(SimpleStackBar), new FrameworkPropertyMetadata(OnSeriesChanged) { BindsTwoWayByDefault = true });
        public BarSeries Series
        {
            get { return GetValue(SeriesProperty) as BarSeries; }
            set
            {
                SetValue(SeriesProperty, value);
            }
        }

        private static void OnSeriesChanged(DependencyObject o, DependencyPropertyChangedEventArgs e)
        {
            var control = o as SimpleStackBar;
            control.UpdateLayout();
            control.InvalidateVisual();
        }


        protected override void OnRender(DrawingContext drawingContext)
        {
            base.OnRender(drawingContext);
            var width = this.ActualWidth;
            var height = this.ActualHeight;
            if (Series == null || Series.DataPoints == null)
                return;
            var total = Series.DataPoints.Sum(d => d.Value);
            var i=0;
            var x = 0d;
            foreach (var dp in Series.DataPoints)
            {
                var percentage =total==0?0:(dp.Value / total);
                var portionOfWidth =percentage * width;
                var brush = dp.Color==null?DefaultBrushes[i]:dp.Color;
                if (portionOfWidth > 0)
                    drawingContext.DrawRectangle(brush, new Pen(brush, 1.0), new Rect(x, 0, portionOfWidth, height));
                x += portionOfWidth;
                i++;
            }
        }
    }
}
